var searchData=
[
  ['b',['b',['../structplplot_1_1__N9.html#a9f68e776f6ef7243bc35e5871aab6383',1,'plplot::_N9::b()'],['../structPLColor.html#aea5b06e2b696b2f99e589ddd594fee34',1,'PLColor::b()'],['../structarc__struct.html#a1f4233061a8d655df47f88e6461b4b1e',1,'arc_struct::b()']]],
  ['b0',['b0',['../defines_8h.html#a23a03d74aaac82e57415808b25a37214',1,'defines.h']]],
  ['b1',['b1',['../defines_8h.html#a4d46c8a35daf7c9b9e71edfae7eb1bce',1,'defines.h']]],
  ['b10',['b10',['../defines_8h.html#a2eea306a54a847b6c8aa626c9e0bab52',1,'defines.h']]],
  ['b11',['b11',['../defines_8h.html#acfb9226f9383f92f03578b36162d1010',1,'defines.h']]],
  ['b12',['b12',['../defines_8h.html#a1459fad47c501c7af7f071af645f88f6',1,'defines.h']]],
  ['b13',['b13',['../defines_8h.html#a6743201ec229dd4b2d80a7fef66fff85',1,'defines.h']]],
  ['b14',['b14',['../defines_8h.html#a35a97734daf8553fc508ffc38ed044b5',1,'defines.h']]],
  ['b15',['b15',['../defines_8h.html#ad61ff7c0d63e39b0f0363d4785b80e03',1,'defines.h']]],
  ['b2',['b2',['../defines_8h.html#acff3bec713fd324f76ac8042293272bf',1,'defines.h']]],
  ['b3',['b3',['../defines_8h.html#ac950c1944fbd7cd31149ac65d64a170a',1,'defines.h']]],
  ['b4',['b4',['../defines_8h.html#a0ab0d6238080caa43c7e61efd7918d8c',1,'defines.h']]],
  ['b5',['b5',['../defines_8h.html#a3a6038d28bd7d0645aa5fbe68cf1f3aa',1,'defines.h']]],
  ['b6',['b6',['../defines_8h.html#a57543d805ea7503c2b105986fb36a03c',1,'defines.h']]],
  ['b7',['b7',['../defines_8h.html#a6931b59c00b84c1249713e2a5c9ae992',1,'defines.h']]],
  ['b8',['b8',['../defines_8h.html#a3a0b7953f88a87fa2c30cc24f8100c06',1,'defines.h']]],
  ['b9',['b9',['../defines_8h.html#acbb3747fa968fa0c097b0eb54fe7ba28',1,'defines.h']]],
  ['barf',['barf',['../plr_8c.html#a4d46a30bc08cf892f6082abcb9bfa24d',1,'plr.c']]],
  ['base',['base',['../structEscText.html#a27f50fc8ce09a219b990abc6959073e1',1,'EscText::base()'],['../structswig__octave__class.html#ac6a03dae555a63dbc7751aa1dc1c9e55',1,'swig_octave_class::base()']]],
  ['base3x',['base3x',['../structPLStream.html#a7668dd6c3144f760c74d391fb53accbe',1,'PLStream']]],
  ['base3y',['base3y',['../structPLStream.html#ac6604eb5ffb1439c89b1f40c812f7468',1,'PLStream']]],
  ['base_5fcont',['BASE_CONT',['../plplot_8h.html#a615d5bba089363ae37df2a6b33fac010',1,'BASE_CONT():&#160;plplot.h'],['../namespaceplplot.html#a8ad02f0abe82b2c26d28a9ea608e21c6',1,'plplot::BASE_CONT()'],['../namespaceplplotc.html#a69b69bb3044b3fb83c14f09561cb1cf7',1,'plplotc.BASE_CONT()']]],
  ['base_5fday',['base_day',['../structMJDtimeStruct.html#a7a7b02e1fc6ffee218d9ae1b4ad76f18',1,'MJDtimeStruct::base_day()'],['../structTAI__UTC.html#a86a46f8d5627f742cdbd14b0a8d64eae',1,'TAI_UTC::base_day()']]],
  ['base_5fnames',['base_names',['../structswig__lua__class.html#a25f24829385c30c59cec92c91fceca23',1,'swig_lua_class::base_names()'],['../structswig__octave__class.html#a4045c37af980b6aeeb76bc508f1a7560',1,'swig_octave_class::base_names()']]],
  ['basecx',['basecx',['../structPLStream.html#a1cfe7c5e03bfc0b86f2b7890cbc89f18',1,'PLStream']]],
  ['basecy',['basecy',['../structPLStream.html#a777ec80e260e0df42be630ddf2d1f998',1,'PLStream']]],
  ['basename',['BaseName',['../structPLStream.html#aa3615d1af2fac919072ca4e1ec079a95',1,'PLStream']]],
  ['bases',['bases',['../structswig__lua__class.html#a468e2d019d6cff6bbe8fefc8f572420b',1,'swig_lua_class']]],
  ['beginpage',['BeginPage',['../classPlDevice.html#a08516c6db27c87020d3b0fccd13231e7',1,'PlDevice::BeginPage()'],['../classwxPLDevice.html#a908760e63e954c0b5aadc093c8f9e9ef',1,'wxPLDevice::BeginPage()']]],
  ['betw',['BETW',['../plplotP_8h.html#af6c78f36cb8594e9612e7acbcf28e8bb',1,'plplotP.h']]],
  ['betw_5fnbcc',['BETW_NBCC',['../plfill_8c.html#a660527944420239471220a0bfec4c5e2',1,'plfill.c']]],
  ['bgcolor',['bgColor',['../structPlFrame.html#a0a649d61c2f65a42fc3451c6c850293d',1,'PlFrame::bgColor()'],['../structXwDev.html#aa175f8852cb1e51b9a7a93a842db0dab',1,'XwDev::bgcolor()']]],
  ['bhunt_5fsearch',['bhunt_search',['../qsastime_8c.html#ac4ecc71b746168056d0c2ac611504452',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c'],['../qsastimeP_8h.html#a4023570fb0c462f766569147984ea58b',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c']]],
  ['bhunt_5fsearch_5ftest_2ec',['bhunt_search_test.c',['../bhunt__search__test_8c.html',1,'']]],
  ['big_5frecl',['big_recl',['../plshade_8c.html#af0b5c0ec2e072e4bdca795e20a09f7d7',1,'plshade.c']]],
  ['bignumber',['BIGNUMBER',['../nnpi_8c.html#a729f44ea060095f705587bf181fb3709',1,'nnpi.c']]],
  ['bin',['bin',['../classplstream.html#aad778bc5fa73b64be84fa815ef5e755c',1,'plstream']]],
  ['bin_5fdir',['BIN_DIR',['../plplot__config_8h.html#ae17fcd1b9014452d5d23b21e7be729e3',1,'plplot_config.h']]],
  ['binc',['BINC',['../plfill_8c.html#a90bc47b28035fcf2110358c7a5205f89',1,'BINC():&#160;plfill.c'],['../plot3d_8c.html#a90bc47b28035fcf2110358c7a5205f89',1,'BINC():&#160;plot3d.c']]],
  ['bisect',['bisect',['../plshade_8c.html#a041dd6c3423e69a3baad7079a7dec312',1,'plshade.c']]],
  ['black',['Black',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38bac1e9bce8242f443c54c7405223d616cd',1,'plstream.h']]],
  ['blit_5fto_5fx',['blit_to_x',['../cairo_8c.html#ac5666021a1bc9cd52badd9120ad66f5c',1,'cairo.c']]],
  ['blue',['blue',['../structcdImageStruct.html#aae5d4b64a60d375e5bb1e1a7cc8b3b6f',1,'cdImageStruct']]],
  ['bonzai',['BONZAI',['../plstream_8cc.html#ab3cae38b8256ce1cfb6c03bee412310b',1,'plstream.cc']]],
  ['bop',['bop',['../classplstream.html#ae06d098b31cd579cd41d81f5db1c6be8',1,'plstream::bop()'],['../metadefs_8h.html#a857adfef718262ca4a28b3648c56de5c',1,'BOP():&#160;metadefs.h']]],
  ['bop0',['BOP0',['../metadefs_8h.html#a7602e5c62ddc385d9df6c96b898f889f',1,'metadefs.h']]],
  ['bop_5fdata',['bop_data',['../structPLStream.html#ad60fe1add202f6c12ee8f6e3f4546962',1,'PLStream']]],
  ['bop_5fhandler',['bop_handler',['../structPLStream.html#a26c8a1f3efd41ea03060695a8eb2df5b',1,'PLStream']]],
  ['bopcmd',['bopCmd',['../structPlFrame.html#a0015cea9695cf72b89638874148148b2',1,'PlFrame::bopCmd()'],['../structPlPlotter.html#a6e828a8cb52aaad71314661f2cab39d3',1,'PlPlotter::bopCmd()']]],
  ['border',['border',['../structPlFrame.html#ae6cd88baa34aa30ef958d96c5a399336',1,'PlFrame::border()'],['../structPlPlotter.html#a7b947ac76bd574078c465ebf457611d0',1,'PlPlotter::border()'],['../structTkwDev.html#a4cc81954b003b8bfa80c4b4dcfe9f051',1,'TkwDev::border()'],['../structXwDev.html#a566d91035d635b24101552997b479bd5',1,'XwDev::border()']]],
  ['borderwidth',['borderWidth',['../structPlFrame.html#a88adc0ded0381397e89b8f28ab8a68ff',1,'PlFrame::borderWidth()'],['../structPlPlotter.html#a5e53528a880abb2eeba413e7bd370272',1,'PlPlotter::borderWidth()']]],
  ['box',['box',['../classplstream.html#ac61565fc7b11af20d18b49a085af1071',1,'plstream']]],
  ['box3',['box3',['../classplstream.html#a98036fa884d2a01a13ba3b409582827d',1,'plstream']]],
  ['boxbb_5fxmax',['boxbb_xmax',['../structPLStream.html#ad7882678b4080b91ab91bdb74759211a',1,'PLStream']]],
  ['boxbb_5fxmin',['boxbb_xmin',['../structPLStream.html#ab37fa0272b8b6680de67e355dfff0f22',1,'PLStream']]],
  ['boxbb_5fymax',['boxbb_ymax',['../structPLStream.html#a7a075f5767e8505ff2ab5d2b0ad03fe1',1,'PLStream']]],
  ['boxbb_5fymin',['boxbb_ymin',['../structPLStream.html#a42239283478e0954e432bfaf0ee569f4',1,'PLStream']]],
  ['bp',['bp',['../structPDFstrm.html#a5c20dd538504c272832b2d06fbafa9ef',1,'PDFstrm']]],
  ['braindead',['BRAINDEAD',['../plplot_8h.html#a397833bd03deddc81a012b416c10bc8f',1,'plplot.h']]],
  ['breakdownmjd',['breakDownMJD',['../qsastime_8c.html#a7e006df720f4dad12fc0f64f9e2e4e84',1,'breakDownMJD(int *year, int *month, int *day, int *hour, int *min, double *sec, const MJDtime *MJD, int forceJulian):&#160;qsastime.c'],['../qsastimeP_8h.html#a5fb852c7385522e8c4cd10f1b05a3bdd',1,'breakDownMJD(int *year, int *month, int *day, int *hour, int *min, double *sec, const MJDtime *MJD, int forceJulian):&#160;qsastime.c']]],
  ['btime',['btime',['../classplstream.html#a8d930554eddade61d8cee0fa029bae9f',1,'plstream']]],
  ['btimeqsas',['btimeqsas',['../qsastime_8c.html#a7305589289ca3100d933219768b6eb95',1,'btimeqsas(int *year, int *month, int *day, int *hour, int *min, double *sec, double ctime, QSASConfig *qsasconfig):&#160;qsastime.c'],['../qsastime_8h.html#ac57c643f9118449188d38b77604df2a0',1,'btimeqsas(int *year, int *month, int *day, int *hour, int *min, double *sec, double ctime, QSASConfig *qsasconfig):&#160;qsastime.c']]],
  ['buf',['buf',['../classoctave__swig__packed.html#aafa28d245f66d78713852cec79856a1b',1,'octave_swig_packed::buf()'],['../tclAPI_8c.html#a095f0dd49eb8681e3a9d4632a98bb06e',1,'buf():&#160;tclAPI.c']]],
  ['buffer',['buffer',['../structPLmDev.html#ad2db6f517d0d7e667f4be48c0b74f908',1,'PLmDev::buffer()'],['../structPDFstrm.html#a5a2125c9b181ce2413fb880b089ba273',1,'PDFstrm::buffer()'],['../structplbuffer.html#abe2c42e7bb486793b4b6d715ce51528a',1,'plbuffer::buffer()'],['../plfill_8c.html#ab670e03eef9a6c21f69d1ad25cce325d',1,'buffer():&#160;plfill.c']]],
  ['buffer2_5fsize',['BUFFER2_SIZE',['../plcore_8c.html#ae0194ede027b49240cc0a7d722d581ed',1,'plcore.c']]],
  ['buffer_5ffifo',['BUFFER_FIFO',['../plframe_8c.html#a04c663298eaf65b3d78f80539ac4e7d9',1,'plframe.c']]],
  ['buffer_5fsize',['buffer_size',['../structPLmDev.html#a730ba640e6aa87b540a660e1ece71c40',1,'PLmDev::buffer_size()'],['../plcore_8c.html#a6b20d41d6252e9871430c242cb1a56e7',1,'BUFFER_SIZE():&#160;plcore.c'],['../plctrl_8c.html#a6b20d41d6252e9871430c242cb1a56e7',1,'BUFFER_SIZE():&#160;plctrl.c'],['../tkMain_8c.html#a6b20d41d6252e9871430c242cb1a56e7',1,'BUFFER_SIZE():&#160;tkMain.c']]],
  ['bufferleng',['bufferleng',['../plfill_8c.html#a7bdd477ac28c7831f20adcae276b133d',1,'plfill.c']]],
  ['buffersize',['buffersize',['../plfill_8c.html#ac3b4ce1692e5a865e1f804cab9a7dad3',1,'plfill.c']]],
  ['bufmax',['bufmax',['../structPDFstrm.html#a29e8d3996ab88bb7906c434e2b8159da',1,'PDFstrm::bufmax()'],['../structPLStream.html#aed8924bacb8ff9e70b92493dcb91b17d',1,'PLStream::bufmax()']]],
  ['bufsize',['BUFSIZE',['../nncommon_8c.html#aeca034f67218340ecb2261a22c2f3dcd',1,'nncommon.c']]],
  ['build_5fdir',['BUILD_DIR',['../plplot__config_8h.html#a40ae373788da1701b1df883e62b46373',1,'plplot_config.h']]],
  ['buildlist',['buildlist',['../plfill_8c.html#a10842154848df7e58bfe1b0698082edd',1,'buildlist(PLINT, PLINT, PLINT, PLINT, PLINT, PLINT, PLINT):&#160;plfill.c'],['../plfill_8c.html#a1db96be13602134cdb90815f0f14aae0',1,'buildlist(PLINT xp1, PLINT yp1, PLINT xp2, PLINT yp2, PLINT PL_UNUSED(xp3), PLINT yp3, PLINT dinc):&#160;plfill.c']]],
  ['button',['button',['../structplplot_1_1__N2.html#a05930baa71b889a734634b1f29df5bec',1,'plplot::_N2::button()'],['../structplplot__graphics_1_1plgraphicsin.html#aa3e888f600b88cc67f344cda61e8d3bd',1,'plplot_graphics::plgraphicsin::button()'],['../structPLGraphicsIn.html#ae17f938017e1c95e5d8cd89ffa836934',1,'PLGraphicsIn::button()'],['../classplplotc_1_1PLGraphicsIn.html#af94b51a13660df83880f29d594d0ea03',1,'plplotc.PLGraphicsIn.button()']]],
  ['buttoneh',['ButtonEH',['../structPLStream.html#ac8f51f07b6f9ebd5d22b0a026867c31a',1,'PLStream']]],
  ['buttoneh_5fdata',['ButtonEH_data',['../structPLStream.html#a0ebf6193b59ba88317034f0f5421a7cf',1,'PLStream']]],
  ['bytecnt',['bytecnt',['../structPLStream.html#a2bae14e39334897df7684da4a7d319fe',1,'PLStream']]],
  ['bytemax',['bytemax',['../structPLStream.html#afa8cd5d4c8ac54d5308dc548991a3fee',1,'PLStream']]],
  ['bytestoend',['bytestoend',['../structcdImageStruct.html#a60db5d7fa1ab556aa0d4a6724dd1b98c',1,'cdImageStruct']]]
];
